@@ -1,11 +1,11 @@
 #' Gamma
 #'
-#' Simple wrapper for \link[ryouready]{ord.gamma}.
+#' Simple wrapper for [ryouready::ord.gamma].
 #'
-#' @param x A \code{table} or dependent numeric variable.
+#' @param x A `table` or dependent numeric variable.
 #' @param y Empty or independent grouping variable
 #'
-#' @return \code{numeric} of length 1.
+#' @return `numeric` of length 1.
 #' @export
 #' @importFrom ryouready ord.gamma
 #' @examples
@@ -23,12 +23,12 @@ ord_gamma <- function(x, y = NULL){
 
 #' Somers' D
 #'
-#' Very simple wrapper for \link[ryouready]{ord.somers.d}.
-#' @param x Dependent variable. Alternatively a \code{table}.
+#' Very simple wrapper for [ryouready::ord.somers.d].
+#' @param x Dependent variable. Alternatively a `table`.
 #' @param y Independent variable
-#' @param symmetric If \code{TRUE}, symmetric D is returned. Default is \code{FALSE}.
-#' @param reverse If \code{TRUE}, row and column variable are switched.
-#' @return \code{numeric} value
+#' @param symmetric If `TRUE`, symmetric D is returned. Default is `FALSE`.
+#' @param reverse If `TRUE`, row and column variable are switched.
+#' @return `numeric` value
 #' @export
 #' @importFrom ryouready ord.somers.d
 #' @examples
@@ -48,13 +48,13 @@ ord_somers_d <- function(x, y = NULL, symmetric = FALSE, reverse = FALSE){
 
 #' Various Tau Statistics
 #'
-#' A wrapper for the appropriate functions form \link{DescTools} to calculate
+#' A wrapper for the appropriate functions from [DescTools] to calculate
 #' Tau A, B and C.
-#' @param x Dependent variable. Alternatively a \code{table}.
+#' @param x Dependent variable. Alternatively a `table`.
 #' @param y Independent variable
-#' @param tau Which of the Taus to return. Default is \code{"b"}.
-#' @param reverse If \code{TRUE}, row and column variable are switched.
-#' @return \code{numeric} value
+#' @param tau Which of the Taus to return. Default is `"b"`.
+#' @param reverse If `TRUE`, row and column variable are switched.
+#' @return `numeric` value
 #' @export
 #' @importFrom DescTools KendallTauA
 #' @importFrom DescTools StuartTauC
@@ -84,11 +84,11 @@ ord_tau <- function(x, y = NULL, tau = "b", reverse = FALSE) {
 #' Get all the ordinal stats
 #'
 #' As of now, only Gamma and Somers D are supported. But let's be honest: Everybody hates Tau.
-#' @param x Dependent variable. Alternatively a \code{table}.
+#' @param x Dependent variable. Alternatively a `table`.
 #' @param y Independent variable
 #' @param round Ho many digits should be rounded. Default is 2.
-#' @param print Print method. Passed to \link[pixiedust]{sprinkle_print_method} as of now.
-#' @return A \code{dust} object, depending on \code{print}.
+#' @param print Print method. Passed to [pixiedust::sprinkle_print_method] as of now.
+#' @return A `dust` object, depending on `print`.
 #' @export
 #' @import pixiedust
 #' @family Tadaa-functions
@@ -102,29 +102,32 @@ tadaa_ord <- function(x, y = NULL, round = 2, print = "console"){
   gamma  <- round(ord_gamma(x), round)
 
   somer_x <- round(ord_somers_d(x), round)
-  #somer_y <- round(ord_somers_d(x, reverse = T), round)
+  somer_y <- round(ord_somers_d(x, reverse = T), round)
   somer_s <- round(ord_somers_d(x, symmetric = T), round)
 
   tau_a <- round(ord_tau(x, tau = "a"), round)
   tau_b <- round(ord_tau(x, tau = "b"), round)
   tau_c <- round(ord_tau(x, tau = "c"), round)
 
-  ret <- data.frame("gamma" = gamma, "somer_x" = somer_x, "somer_s" = somer_s,
+  ret <- data.frame("gamma" = gamma,
+                    "somer_x" = somer_x, "somer_y" = somer_y, "somer_s" = somer_s,
                     "tau_a" = tau_a, "tau_b" = tau_b, "tau_c" = tau_c)
 
   if (print != "markdown") {
     retprint <- pixiedust::sprinkle_colnames(pixiedust::dust(ret),
                                              gamma = "Gamma",
-                                             somer_x = "Somers' D",
-                                             somer_s = "Somers' D (sym.)",
+                                             somer_x = "D (x)",
+                                             somer_y = "D (y)",
+                                             somer_s = "D (xy)",
                                              tau_a = "Tau A",
                                              tau_b = "Tau B",
                                              tau_c = "Tau C")
   } else {
     retprint <- pixiedust::sprinkle_colnames(pixiedust::dust(ret),
                                              gamma = "$\\gamma$",
-                                             somer_x = "Somers' D",
-                                             somer_s = "Somers' D (sym.)",
+                                             somer_x = "$D_x$",
+                                             somer_y = "$D_y$",
+                                             somer_s = "$D_{xy}$",
                                              tau_a = "$\\tau_A$",
                                              tau_b = "$\\tau_B$",
                                              tau_c = "$\\tau_C$")
